## Janitor

[![Build Status](https://travis-ci.org/vedantrathore/janitor.svg?branch=master)](https://travis-ci.org/vedantrathore/janitor)

The Easiest way to clean and analyse your files!

### Installation

* Install python and pip according to your system with the guide available [here](http://docs.python-guide.org/en/latest/starting/installation/)
* ` pip install janitor-cleaner `

### Usage

* open the directory of your choice in a terminal/command prompt
```
Usage: janitor [OPTIONS] COMMAND [ARGS]...

  A simple command line tool to clean and analyse your file system

Options:
  --help  Show this message and exit.

Commands:
  analyse  Analyse the directory
  clean    Clean your unwanted files to a secure location of your choice
```
* add `--help` to check command arguments
